==> v11.0.1.zip: brewman/overlord/src/app/shared/image.service.ts <==
import { Injectable } from '@angular/core';
import { fromEvent, of, zip } from 'rxjs';
import { map } from 'rxjs/operators';

import { DbFile } from '../core/db-file';
import { Voucher } from '../core/voucher';

@Injectable({
  providedIn: 'root',
})
export class ImageService {
  resizeImage(image: string, maxWidth: number, maxHeight: number) {
    const canvas = document.createElement('canvas');
    const ctx = canvas.getContext('2d') as CanvasRenderingContext2D;
    const img = new Image();
    const ex = fromEvent(img, 'load').pipe(
      map(() => {
        let width = img.naturalWidth;
        let height = img.naturalHeight;
        const ratio = Math.min(1, maxWidth / width, maxHeight / height);

        if (ratio === 1) {
          return image;
        }

        width *= ratio;
        height *= ratio;

        canvas.width = width;
        canvas.height = height;
        ctx.drawImage(img, 0, 0, width, height);
        return canvas.toDataURL('image/jpeg', 0.95);
      }),
    );
    img.src = image;
    return ex;
  }

  detectFiles(event: Event, voucher: Voucher) {
    // const { files } = event.target as HTMLInputElement;
    const fileList = (event.target as HTMLInputElement).files;
    if (fileList === null) {
      return;
    }
    for (const file of Array.from(fileList)) {
      const reader = new FileReader();
      reader.onload = (e) => {
        const target = e.target as FileReader;
        zip(
          of(target.result),
          this.resizeImage(target.result as string, 100, 150),
          this.resizeImage(target.result as string, 825, 1170),
        ).subscribe((val) =>
          voucher.files.push(new DbFile({ thumbnail: val[1], resized: val[2] })),
        );
      };
      reader.readAsDataURL(file);
    }
  }
}

==> v11.1.5.zip: brewman/overlord/src/app/shared/image.service.ts <==
import { Injectable } from '@angular/core';
import { fromEvent, of, zip } from 'rxjs';
import { map } from 'rxjs/operators';

import { DbFile } from '../core/db-file';
import { Voucher } from '../core/voucher';

@Injectable({
  providedIn: 'root',
})
export class ImageService {
  resizeImage(image: string, maxWidth: number, maxHeight: number) {
    const canvas = document.createElement('canvas');
    const ctx = canvas.getContext('2d') as CanvasRenderingContext2D;
    const img = new Image();
    const ex = fromEvent(img, 'load').pipe(
      map(() => {
        let width = img.naturalWidth;
        let height = img.naturalHeight;
        const ratio = Math.min(1, maxWidth / width, maxHeight / height);

        if (ratio === 1) {
          return image;
        }

        width *= ratio;
        height *= ratio;

        canvas.width = width;
        canvas.height = height;
        ctx.drawImage(img, 0, 0, width, height);
        return canvas.toDataURL('image/jpeg', 0.95);
      }),
    );
    img.src = image;
    return ex;
  }

  detectFiles(event: Event, voucher: Voucher) {
    // const { files } = event.target as HTMLInputElement;
    const fileList = (event.target as HTMLInputElement).files;
    if (fileList === null) {
      return;
    }
    for (const file of Array.from(fileList)) {
      const reader = new FileReader();
      reader.onload = (e) => {
        const target = e.target as FileReader;
        zip(
          of(target.result),
          this.resizeImage(target.result as string, 100, 150),
          this.resizeImage(target.result as string, 825, 1170),
        ).subscribe((val) => voucher.files.push(new DbFile({ thumbnail: val[1], resized: val[2] })));
      };
      reader.readAsDataURL(file);
    }
  }
}
